#[repr(C)]pub struct PdPluginInfo {
pub name: *const u8,
pub name_len: u32,
pub version_major: u32,
pub version_minor: u32,
pub version_patch: u32,
pub abi_version: u32,
pub actor_type_count: u32,
pub actor_types: *const PdActorTypeInfo,
}Expand description
Top-level plugin metadata returned by the pd_plugin_init export.
The engine reads this struct immediately after calling pd_plugin_init.
All pointed-to data must remain valid until pd_plugin_shutdown returns.
Fields
name: *const u8UTF-8 plugin name — not null-terminated.
name_len: u32Byte length of name.
version_major: u32Semantic version — major component.
version_minor: u32Semantic version — minor component.
version_patch: u32Semantic version — patch component.
abi_version: u32Must equal PD_ABI_VERSION; the engine rejects mismatches with
PluginError::AbiMismatch.
actor_type_count: u32Number of elements in the actor_types array.
actor_types: *const PdActorTypeInfoPointer to the first element of an array of PdActorTypeInfo.